@@ -52,7 +52,7 @@ class HomeWindow(QMainWindow, Ui_HomeWindow):
         self.show()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
         self.restoreSettings()
-        QTimer.singleShot(3000,  self.youtubeLogin)
+        self.youtubeLogin()
         
     def changeButtonStyleSheet(self):
         """
