@@ -379,13 +379,10 @@ class YouTubeVideoPlayer(QThread):
             os.system(playbackCommand % filename.encode("utf-8"))
         else:
             videoUrl = YouTubeDataService.getVideoUrl(self.video,  YouTubeVideoPlayer.playbackFormat)
-            os.system(playbackCommand % videoUrl)  
+            os.system(playbackCommand % videoUrl) 
 
     def run(self):
-        if self.video != None:
-            self.playYouTubeVideo()
-        else:
-            self.createAndPlayPlaylist()
+        self.playYouTubeVideo()
 
 class YouTubeVideoDownloader(object):
     """
